@@ -8,15 +8,11 @@ from browsercontroller.helper import (
 )
 from typeguard import typechecked
 
-from src.gitbrowserinteract.export_token import (
-    export_github_pac_to_personal_creds_txt,
-)
-from src.gitbrowserinteract.GitHub.github_login import github_login
-from src.gitbrowserinteract.GitHub.remove_previous_github_pat import (
-    remove_previous_github_pat,
-)
-from src.gitbrowserinteract.Hardcoded import Hardcoded
-from src.gitbrowserinteract.helper import get_value_from_html_source
+from ..export_token import export_github_pac_to_personal_creds_txt
+from ..GitHub.github_login import github_login
+from ..GitHub.remove_previous_github_pat import remove_previous_github_pat
+from ..Hardcoded import Hardcoded
+from ..helper import get_value_from_html_source
 
 
 class Github_personal_access_token_getter:
@@ -154,7 +150,7 @@ class Github_personal_access_token_getter:
         self.click_submit_token(driver, hardcoded)
 
     @typechecked
-    def click_repo_status_checkbox(self, driver, hardcoded):
+    def click_repo_status_checkbox(self, driver, hardcoded: Hardcoded):
         """
 
         :param driver:
@@ -198,7 +194,7 @@ class Github_personal_access_token_getter:
             )
 
     @typechecked
-    def click_submit_token(self, driver, hardcoded):
+    def click_submit_token(self, driver, hardcoded: Hardcoded):
         """
 
         :param driver:
