@@ -1,12 +1,14 @@
 """Asks user input through CLI."""
+from getpass import getpass
+
 from typeguard import typechecked
 
 
 @typechecked
-def ask_two_factor_code():
+def ask_two_factor_code() -> str:
     """Asks for the 2fac.
 
-    TODO: make save, hide code instead of displaying on terminal.
+    TODO: make safe, hide code instead of displaying on terminal.
     """
     two_fac_code = get_input(
         text="Please enter the two factor authentication you just received:"
@@ -15,10 +17,9 @@ def ask_two_factor_code():
 
 
 @typechecked
-def get_input(*, text):
-    """
+def get_input(*, text: str) -> str:
+    """Asks user input through CLI.
 
     :param text:
-
     """
-    return input(text)
+    return getpass(text)
