@@ -1,6 +1,8 @@
 """Controls a firefox or chromium browser instance to allow automation of
 setting a GitHub SSH deploy key, GitHub personal access token, or getting a
 GitLab runner token."""
+from typing import Any
+
 from selenium.common.exceptions import TimeoutException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
@@ -9,7 +11,7 @@ from typeguard import typechecked
 
 
 @typechecked
-def wait_until_page_is_loaded(*, time_limit_sec: int, driver):
+def wait_until_page_is_loaded(*, time_limit_sec: int, driver: Any) -> None:
     """Waits untill page is loaded for some time frame."""
     delay = time_limit_sec  # seconds
     try:
